==> pant-react-0.2.2.tgz: package/es/datetime-picker/datetime-rage.js <==
var __extends = (this && this.__extends) || (function () {
    var extendStatics = function (d, b) {
        extendStatics = Object.setPrototypeOf ||
            ({ __proto__: [] } instanceof Array && function (d, b) { d.__proto__ = b; }) ||
            function (d, b) { for (var p in b) if (Object.prototype.hasOwnProperty.call(b, p)) d[p] = b[p]; };
        return extendStatics(d, b);
    };
    return function (d, b) {
        if (typeof b !== "function" && b !== null)
            throw new TypeError("Class extends value " + String(b) + " is not a constructor or null");
        extendStatics(d, b);
        function __() { this.constructor = d; }
        d.prototype = b === null ? Object.create(b) : (__.prototype = b.prototype, new __());
    };
})();
var __assign = (this && this.__assign) || function () {
    __assign = Object.assign || function(t) {
        for (var s, i = 1, n = arguments.length; i < n; i++) {
            s = arguments[i];
            for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p))
                t[p] = s[p];
        }
        return t;
    };
    return __assign.apply(this, arguments);
};
import { jsx as _jsx, jsxs as _jsxs } from "react/jsx-runtime";
import React from 'react';
import { Popup } from '../popup';
import { i18n } from '../locale';
import { DatetimePicker } from '.';
import { createBEM } from '../utils/bem';
import './index.scss';
var bem = createBEM('pant-datetime-range');
var DatetimeRange = /** @class */ (function (_super) {
    __extends(DatetimeRange, _super);
    function DatetimeRange(props) {
        var _this = _super.call(this, props) || this;
        var defaultValue = props.defaultValue || [];
        _this.state = {
            step: 1,
            startDate: defaultValue[0],
            endDate: defaultValue[1],
        };
        _this.closePopup = _this.closePopup.bind(_this);
        _this.onConfirm1 = _this.onConfirm1.bind(_this);
        _this.onConfirm2 = _this.onConfirm2.bind(_this);
        return _this;
    }
    DatetimeRange.prototype.getValue = function () {
        var _a = this.state, startDate = _a.startDate, endDate = _a.endDate;
        if (!startDate || !endDate) {
            return null;
        }
        return [startDate, endDate];
    };
    DatetimeRange.prototype.clearValue = function (cb) {
        this.setState({ startDate: null, endDate: null }, cb);
    };
    DatetimeRange.prototype.closePopup = function (confirm) {
        var _a = this.props, closePopup = _a.closePopup, onCancel = _a.onCancel;
        if (!confirm) {
            this.setState({ step: 1 }, function () {
                closePopup && closePopup();
                onCancel && onCancel();
            });
        }
    };
    DatetimeRange.prototype.onConfirm1 = function (date) {
        this.setState({ step: 2, startDate: date });
    };
    DatetimeRange.prototype.onConfirm2 = function (date) {
        var _this = this;
        var _a = this.props, closePopup = _a.closePopup, onConfirm = _a.onConfirm;
        this.setState({ step: 1, endDate: date }, function () {
            closePopup && closePopup(true);
            onConfirm && onConfirm(_this.getValue());
        });
    };
    DatetimeRange.prototype.render = function () {
        var _a = this.props, show = _a.show, type = _a.type, seconds = _a.seconds, min = _a.min, max = _a.max, titleStart = _a.titleStart, titleEnd = _a.titleEnd, confirmButtonText = _a.confirmButtonText, cancelButtonText = _a.cancelButtonText, prefixZero = _a.prefixZero, seperator = _a.seperator, roundPopup = _a.roundPopup, formatter = _a.formatter, toolbarPosition = _a.toolbarPosition;
        var _b = this.state, step = _b.step, startDate = _b.startDate, endDate = _b.endDate;
        return (_jsxs("div", __assign({ className: bem([type, { seconds: seconds, seperator: seperator }]) }, { children: [_jsx(Popup, __assign({ position: "bottom", show: show && step === 1, closePopup: this.closePopup, round: roundPopup, closeOnClickOverlay: true }, { children: _jsx(DatetimePicker, { title: titleStart, confirmButtonText: confirmButtonText, cancelButtonText: cancelButtonText, type: type, seconds: seconds, min: min, max: max, prefixZero: prefixZero, seperator: seperator, formatter: formatter, toolbarPosition: toolbarPosition, onConfirm: this.onConfirm1, defaultValue: startDate }, Date.now()) }), void 0),
                _jsx(Popup, __assign({ position: "bottom", show: show && step === 2, closePopup: this.closePopup, round: roundPopup, closeOnClickOverlay: true }, { children: _jsx(DatetimePicker, { title: titleEnd, confirmButtonText: confirmButtonText, cancelButtonText: cancelButtonText, type: type, seconds: seconds, min: startDate || min, max: max, prefixZero: prefixZero, seperator: seperator, formatter: formatter, toolbarPosition: toolbarPosition, onConfirm: this.onConfirm2, defaultValue: endDate }, Date.now()) }), void 0)] }), void 0));
    };
    DatetimeRange.__FIELD_BEHAVIOR__ = 'Popup';
    DatetimeRange.defaultProps = {
        roundPopup: true,
        titleStart: i18n().selectStartDate,
        titleEnd: i18n().selectEndDate,
        defaultValue: [],
    };
    return DatetimeRange;
}(React.PureComponent));
export { DatetimeRange };

==> pant-react-0.2.4.tgz: package/es/datetime-picker/datetime-rage.js <==
var __extends = (this && this.__extends) || (function () {
    var extendStatics = function (d, b) {
        extendStatics = Object.setPrototypeOf ||
            ({ __proto__: [] } instanceof Array && function (d, b) { d.__proto__ = b; }) ||
            function (d, b) { for (var p in b) if (Object.prototype.hasOwnProperty.call(b, p)) d[p] = b[p]; };
        return extendStatics(d, b);
    };
    return function (d, b) {
        if (typeof b !== "function" && b !== null)
            throw new TypeError("Class extends value " + String(b) + " is not a constructor or null");
        extendStatics(d, b);
        function __() { this.constructor = d; }
        d.prototype = b === null ? Object.create(b) : (__.prototype = b.prototype, new __());
    };
})();
var __assign = (this && this.__assign) || function () {
    __assign = Object.assign || function(t) {
        for (var s, i = 1, n = arguments.length; i < n; i++) {
            s = arguments[i];
            for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p))
                t[p] = s[p];
        }
        return t;
    };
    return __assign.apply(this, arguments);
};
import { jsx as _jsx, jsxs as _jsxs } from "react/jsx-runtime";
import React from 'react';
import { Popup } from '../popup';
import { i18n } from '../locale';
import { DatetimePicker } from '.';
import { createBEM } from '../utils/bem';
import './index.scss';
var bem = createBEM('pant-datetime-range');
var DatetimeRange = /** @class */ (function (_super) {
    __extends(DatetimeRange, _super);
    function DatetimeRange(props) {
        var _this = _super.call(this, props) || this;
        var defaultValue = props.defaultValue || [];
        _this.state = {
            step: 1,
            startDate: defaultValue[0],
            endDate: defaultValue[1],
        };
        _this.closePopup = _this.closePopup.bind(_this);
        _this.onConfirm1 = _this.onConfirm1.bind(_this);
        _this.onConfirm2 = _this.onConfirm2.bind(_this);
        return _this;
    }
    DatetimeRange.prototype.getValue = function () {
        var _a = this.state, startDate = _a.startDate, endDate = _a.endDate;
        if (!startDate || !endDate) {
            return null;
        }
        return [startDate, endDate];
    };
    DatetimeRange.prototype.clearValue = function (cb) {
        this.setState({ startDate: null, endDate: null }, cb);
    };
    DatetimeRange.prototype.closePopup = function (confirm) {
        var _a = this.props, closePopup = _a.closePopup, onCancel = _a.onCancel;
        if (!confirm) {
            this.setState({ step: 1 }, function () {
                closePopup && closePopup();
                onCancel && onCancel();
            });
        }
    };
    DatetimeRange.prototype.onConfirm1 = function (date) {
        this.setState({ step: 2, startDate: date });
    };
    DatetimeRange.prototype.onConfirm2 = function (date) {
        var _this = this;
        var _a = this.props, closePopup = _a.closePopup, onConfirm = _a.onConfirm;
        this.setState({ step: 1, endDate: date }, function () {
            closePopup && closePopup(true);
            onConfirm && onConfirm(_this.getValue());
        });
    };
    DatetimeRange.prototype.render = function () {
        var _a = this.props, show = _a.show, type = _a.type, seconds = _a.seconds, min = _a.min, max = _a.max, titleStart = _a.titleStart, titleEnd = _a.titleEnd, confirmButtonText = _a.confirmButtonText, cancelButtonText = _a.cancelButtonText, prefixZero = _a.prefixZero, seperator = _a.seperator, roundPopup = _a.roundPopup, formatter = _a.formatter, toolbarPosition = _a.toolbarPosition;
        var _b = this.state, step = _b.step, startDate = _b.startDate, endDate = _b.endDate;
        return (_jsxs("div", __assign({ className: bem([type, { seconds: seconds, seperator: seperator }]) }, { children: [_jsx(Popup, __assign({ position: "bottom", show: show && step === 1, closePopup: this.closePopup, round: roundPopup, closeOnClickOverlay: true }, { children: _jsx(DatetimePicker, { title: titleStart || i18n().selectStartDate, confirmButtonText: confirmButtonText, cancelButtonText: cancelButtonText, type: type, seconds: seconds, min: min, max: max, prefixZero: prefixZero, seperator: seperator, formatter: formatter, toolbarPosition: toolbarPosition, onConfirm: this.onConfirm1, defaultValue: startDate }, Date.now()) }), void 0),
                _jsx(Popup, __assign({ position: "bottom", show: show && step === 2, closePopup: this.closePopup, round: roundPopup, closeOnClickOverlay: true }, { children: _jsx(DatetimePicker, { title: titleEnd || i18n().selectEndDate, confirmButtonText: confirmButtonText, cancelButtonText: cancelButtonText, type: type, seconds: seconds, min: startDate || min, max: max, prefixZero: prefixZero, seperator: seperator, formatter: formatter, toolbarPosition: toolbarPosition, onConfirm: this.onConfirm2, defaultValue: endDate }, Date.now()) }), void 0)] }), void 0));
    };
    DatetimeRange.__FIELD_BEHAVIOR__ = 'Popup';
    DatetimeRange.defaultProps = {
        roundPopup: true,
        defaultValue: [],
    };
    return DatetimeRange;
}(React.PureComponent));
export { DatetimeRange };
